@@ -19,7 +19,7 @@
 # ***** END LICENSE BLOCK *****
 
 __author__  = "Hayaki Saito (user@zuse.jp)"
-__version__ = "0.1.5"
+__version__ = "0.1.7"
 __license__ = "GPL v3"
 
 import os
@@ -28,14 +28,22 @@ import optparse
 import select
 import logging
 
-try:
-    from cStringIO import StringIO
-except:
-    from StringIO import StringIO
-
 from sixel import SixelWriter, SixelConverter
 from cellsize import CellSizeDetector
 
+
+def _filenize(f):
+    import stat
+
+    mode = os.fstat(f.fileno()).st_mode
+    if stat.S_ISFIFO(mode) or os.isatty(f.fileno()):
+        try:
+            from cStringIO import StringIO
+        except ImportError:
+            from StringIO import StringIO
+        return StringIO(f.read())
+    return f
+
 def main():
 
     parser = optparse.OptionParser()
@@ -101,6 +109,12 @@ def main():
                       default=256,
                       help="Specify number of colors")
 
+    parser.add_option("-b", "--body-only",
+                      action="store_true",
+                      dest="bodyonly",
+                      default=False,
+                      help="Output sixel without header and DCS envelope")
+
     options, args = parser.parse_args()
 
     rcdir = os.path.join(os.getenv("HOME"), ".pysixel")
@@ -154,12 +168,13 @@ def main():
             else:
                 height = int(height) * char_height
                
-    writer = sixel.SixelWriter(f8bit=options.f8bit)
+    writer = sixel.SixelWriter(f8bit=options.f8bit,
+                               bodyonly=options.bodyonly)
 
     if select.select([stdin, ], [], [], 0.0)[0]:
-        imagefile = stdin
+        imagefile = _filenize(stdin)
     elif len(args) == 0 or args[0] == '-':
-        imagefile = stdin
+        imagefile = _filenize(stdin)
     else:
         imagefile = args[0]
 
@@ -173,5 +188,6 @@ def main():
                 ncolor=int(options.ncolor),
                 alphathreshold=options.alphathreshold,
                 chromakey=options.chromakey) 
+
 if __name__ == '__main__':
     main()
